import "./Autocomplete.css";
import { wrappedInputPropsAdapter } from "../../input";
import { Box } from "../../box";
import { HiddenAutocomplete } from "./HiddenAutocomplete";
import { Keys, augmentElement, isNil, isNilOrEmpty, mergeProps, useControllableState, useEventCallback, useFocusWithin, useId, useMergedRefs, useRefState } from "../../shared";
import { Listbox, OptionKeyProp } from "../../listbox";
import { Overlay, isDevToolsBlurEvent, isTargetParent, usePopup, useTriggerWidth } from "../../overlay";
import { SearchInput } from "../../text-input";
import { useFieldInputProps } from "../../field";
import { forwardRef, useCallback, useRef, useState } from "react";
import { getItemText, useCollectionSearch, useOnlyCollectionItems } from "../../collection";
import { useDebouncedCallback } from "./useDebouncedCallback";
import { useDeferredValue } from "./useDeferredValue";
import { useInputGroupTextInputProps } from "../../input-group";
import { jsx as _jsx } from "react/jsx-runtime";
import { Fragment as _Fragment } from "react/jsx-runtime";
import { jsxs as _jsxs } from "react/jsx-runtime";
const DefaultElement = "input";
export function InnerAutocomplete(props) {
  var _ref;

  const [fieldProps] = useFieldInputProps();
  const [inputGroupProps] = useInputGroupTextInputProps();
  const contextualProps = mergeProps(fieldProps, inputGroupProps);
  const {
    active,
    align = "start",
    allowFlip = true,
    allowPreventOverflow = true,
    "aria-describedby": ariaDescribedBy,
    "aria-label": ariaLabel,
    "aria-labelledby": ariaLabelledBy,
    as = DefaultElement,
    autoFocus,
    children,
    clearOnSelect,
    defaultOpen,
    defaultValue,
    direction = "bottom",
    disabled,
    fluid,
    focus,
    forwardedRef,
    hover,
    icon,
    id,
    loading,
    minCharacters = 1,
    name,
    noResultsMessage,
    onOpenChange,
    onSearch,
    onSelectionChange,
    open: openProp,
    overlayProps: {
      id: menuId,
      width: menuWidth,
      ...menuProps
    } = {},
    // Usually provided by the field inputs.
    placeholder,
    readOnly,
    required,
    validationState,
    value: valueProp,
    wrapperProps,
    zIndex = 10000,
    ...rest
  } = mergeProps(props, wrappedInputPropsAdapter(contextualProps));
  const [focusedItem, setFocusedItem] = useState(null);
  const [queryRef, setQuery] = useRefState("");
  const [value, setValue] = useControllableState(valueProp, defaultValue, null, {
    onChange: useCallback((newValue, {
      isControlled,
      isInitial
    }) => {
      // Keep query in sync with the initial or controlled value.
      if (isInitial || isControlled) {
        setQuery(newValue !== null && newValue !== void 0 ? newValue : "");
      }

      return undefined;
    }, [setQuery])
  });
  const triggerWrapperRef = useRef();
  const {
    isOpen,
    overlayProps: {
      ref: overlayRef,
      ...overlayProps
    },
    setIsOpen,
    triggerProps: {
      ref: popupTriggerRef,
      ...triggerProps
    }
  } = usePopup("listbox", {
    allowFlip,
    allowPreventOverflow,
    defaultOpen,
    disabled: disabled || readOnly,
    hideOnEscape: true,
    hideOnLeave: true,
    id: menuId,
    offset: [0, 4],
    onOpenChange,
    open: openProp,
    position: `${direction}-${align}`,
    restoreFocus: true,
    // An autocomplete take care of his own trigger logic.
    trigger: "none"
  });
  const [triggerWidthRef, triggerWidth] = useTriggerWidth();
  const listboxRef = useRef();
  const triggerRef = useMergedRefs(forwardedRef, popupTriggerRef, triggerWidthRef);
  const [results, searchCollection] = useCollectionSearch(children, {
    onSearch
  }); // Required to support selection when there are sections.

  const items = useOnlyCollectionItems(results);
  const open = useCallback(event => {
    setIsOpen(event, true);
  }, [setIsOpen]);
  const close = useCallback(event => {
    setIsOpen(event, false);
    setFocusedItem(null);
  }, [setIsOpen, setFocusedItem]);
  const setSelection = useCallback((event, newKey) => {
    var _newValue;

    let newValue = null;

    if (!isNil(newKey)) {
      const selectedItem = items.find(x => x.key === newKey);

      if (!isNil(selectedItem)) {
        newValue = getItemText(selectedItem);
      }
    }

    if (value !== newValue) {
      setValue(newValue);

      if (!isNil(onSelectionChange)) {
        onSelectionChange(event, isNil(newKey) ? null : {
          key: newKey,
          value: newValue
        });
      }
    }

    setQuery(clearOnSelect ? "" : (_newValue = newValue) !== null && _newValue !== void 0 ? _newValue : "", true);
  }, [items, onSelectionChange, clearOnSelect, value, setValue, setQuery]);
  const clear = useCallback(event => {
    setSelection(event, null);
  }, [setSelection]);
  const reset = useCallback(() => {
    // Reset the value to the last selected one.
    if (value !== queryRef.current) {
      setQuery(value !== null && value !== void 0 ? value : "", true);
    }
  }, [value, queryRef, setQuery]);
  const search = useDebouncedCallback((event, query) => {
    if (query.trim().length >= minCharacters) {
      searchCollection(event, query);
      open(event);
    } else if (isNilOrEmpty(query)) {
      clear(event);
      close(event);
    } else {
      close(event);
    }
  }, 200);
  const selectItem = useCallback((event, key) => {
    setSelection(event, key);
    close(event);
  }, [setSelection, close]);
  const triggerFocusWithinProps = useFocusWithin({
    onBlur: useEventCallback(event => {
      if (!isDevToolsBlurEvent(triggerRef)) {
        // Close the menu when the focus switch from the trigger to somewhere else than the menu or the trigger.
        if (!isTargetParent(event.relatedTarget, triggerWrapperRef.current) && !isTargetParent(event.relatedTarget, overlayRef)) {
          close(event);
          reset();
        }
      }
    })
  });
  const handleTriggerKeyDown = useEventCallback(event => {
    switch (event.key) {
      case Keys.arrowDown:
        if (isOpen) {
          var _listboxRef$current;

          event.preventDefault();
          const activeElement = (_listboxRef$current = listboxRef.current) === null || _listboxRef$current === void 0 ? void 0 : _listboxRef$current.focusManager.focusNext();
          setFocusedItem({
            id: activeElement.id,
            key: activeElement.getAttribute(OptionKeyProp)
          });
        }

        break;

      case Keys.arrowUp:
        if (isOpen) {
          var _listboxRef$current2;

          event.preventDefault();
          const activeElement = (_listboxRef$current2 = listboxRef.current) === null || _listboxRef$current2 === void 0 ? void 0 : _listboxRef$current2.focusManager.focusPrevious();
          setFocusedItem({
            id: activeElement.id,
            key: activeElement.getAttribute(OptionKeyProp)
          });
        }

        break;

      case Keys.home:
        if (isOpen) {
          var _listboxRef$current3;

          event.preventDefault();
          const activeElement = (_listboxRef$current3 = listboxRef.current) === null || _listboxRef$current3 === void 0 ? void 0 : _listboxRef$current3.focusManager.focusFirst();
          setFocusedItem({
            id: activeElement.id,
            key: activeElement.getAttribute(OptionKeyProp)
          });
        }

        break;

      case Keys.end:
        if (isOpen) {
          var _listboxRef$current4;

          event.preventDefault();
          const activeElement = (_listboxRef$current4 = listboxRef.current) === null || _listboxRef$current4 === void 0 ? void 0 : _listboxRef$current4.focusManager.focusLast();
          setFocusedItem({
            id: activeElement.id,
            key: activeElement.getAttribute(OptionKeyProp)
          });
        }

        break;

      case Keys.esc:
        if (isOpen) {
          // Do not remove otherwise the SearchInput will clear the input on esc.
          event.stopPropagation();
          event.preventDefault();
          close(event);
        }

        break;

      case Keys.enter:
        if (isOpen) {
          event.preventDefault();

          if (!isNil(focusedItem)) {
            selectItem(event, focusedItem.key);
          }
        }

        break;
    }
  });
  const handleTriggerChange = useEventCallback((event, query) => {
    setQuery(query, true);
    search(event, query);
  });
  const handleListboxSelectionChange = useEventCallback((event, newKeys) => {
    var _newKeys$;

    selectItem(event, (_newKeys$ = newKeys[0]) !== null && _newKeys$ !== void 0 ? _newKeys$ : null);
  });
  const handleListboxFocusChange = useEventCallback((event, newKey, activeElement) => {
    setFocusedItem({
      id: activeElement.id,
      key: newKey
    });
  });
  const triggerId = useId(id, "o-ui-autocomplete-trigger");
  const iconMarkup = icon && augmentElement(icon, {
    className: "o-ui-autocomplete-icon",
    size: "sm"
  });

  const listboxMarkup = /*#__PURE__*/_jsx(Listbox, {
    "aria-describedby": ariaDescribedBy // An autocomplete doesn't support any persisted selected keys.
    ,
    "aria-label": ariaLabel,
    "aria-labelledby": isNil(ariaLabel) ? ariaLabelledBy !== null && ariaLabelledBy !== void 0 ? ariaLabelledBy : triggerId : undefined,
    className: "o-ui-autocomplete-listbox",
    fluid: true,
    focusOnHover: true,
    nodes: results,
    onFocusChange: handleListboxFocusChange,
    onSelectionChange: handleListboxSelectionChange,
    ref: listboxRef,
    selectedKeys: [],
    tabbable: false,
    useVirtualFocus: true
  });

  const noResultsMarkup = /*#__PURE__*/_jsx(Box, {
    className: "o-ui-autocomplete-no-results",
    children: noResultsMessage !== null && noResultsMessage !== void 0 ? noResultsMessage : "No results found."
  });

  return /*#__PURE__*/_jsxs(_Fragment, {
    children: [/*#__PURE__*/_jsx(HiddenAutocomplete, {
      disabled: disabled,
      name: name,
      required: required,
      validationState: validationState,
      value: value
    }), /*#__PURE__*/_jsx(SearchInput, { ...mergeProps(rest, {
        active,
        "aria-activedescendant": focusedItem === null || focusedItem === void 0 ? void 0 : focusedItem.id,
        "aria-autocomplete": "list",
        "aria-describedby": ariaDescribedBy,
        "aria-label": ariaLabel,
        "aria-labelledby": isNil(ariaLabel) ? ariaLabelledBy : undefined,
        as,
        autoFocus,
        className: "o-ui-autocomplete-trigger",
        disabled,
        fluid,
        focus,
        hover,
        icon: iconMarkup !== null && iconMarkup !== void 0 ? iconMarkup : null,
        id: triggerId,
        loading: useDeferredValue(loading, 100, false),
        onKeyDown: handleTriggerKeyDown,
        onValueChange: handleTriggerChange,
        placeholder,
        readOnly,
        ref: triggerRef,
        role: "combobox",
        type: "text",
        validationState,
        value: queryRef.current,
        wrapperProps: mergeProps(wrapperProps !== null && wrapperProps !== void 0 ? wrapperProps : {}, {
          ref: triggerWrapperRef
        }, triggerFocusWithinProps)
      }, triggerProps)
    }), /*#__PURE__*/_jsx(Overlay, { ...mergeProps(menuProps, {
        className: `o-ui-autocomplete-menu ${results.length > 0 ? "" : "o-ui-autocomplete-menu-no-results"}`,
        ref: overlayRef,
        show: isOpen && (!loading || results.length > 0),
        width: (_ref = menuWidth !== null && menuWidth !== void 0 ? menuWidth : triggerWidth) !== null && _ref !== void 0 ? _ref : undefined,
        zIndex
      }, overlayProps),
      children: results.length > 0 ? listboxMarkup : noResultsMarkup
    })]
  });
}
export const Autocomplete = /*#__PURE__*/forwardRef((props, ref) => /*#__PURE__*/_jsx(InnerAutocomplete, { ...props,
  forwardedRef: ref
}));