import { useCallback, useEffect, useState } from "react";
import { isNil, isPromise, useRefState } from "../../shared";
export function useAsyncSearch(load) {
  const [isLoading, setIsLoading] = useState(false);
  const [items, setItems] = useState([]);
  const [abortController, setAbortController] = useRefState();
  const cancelRequest = useCallback(() => {
    if (!isNil(abortController.current)) {
      abortController.current.abort();
      setAbortController(null);
    }
  }, [abortController, setAbortController]);
  const search = useCallback(async (event, query) => {
    cancelRequest();
    setAbortController(new AbortController());
    setIsLoading(true);
    const loadPromise = load(query, abortController.current.signal);

    if (!isPromise(loadPromise)) {
      throw new Error("Load function must return a valid promise.");
    }

    loadPromise.then(result => {
      setItems(result !== null && result !== void 0 ? result : []);
      setIsLoading(false);
    }).catch(error => {
      // Do not handle cancelled request.
      if (isNil(error) || (error === null || error === void 0 ? void 0 : error.name) !== "AbortError") {
        setItems([]);
        setIsLoading(false);
      }
    });
  }, [load, setIsLoading, setItems, abortController, setAbortController, cancelRequest]);
  useEffect(() => {
    return () => {
      cancelRequest();
    };
  }, [cancelRequest]);
  return {
    isLoading,
    items,
    search
  };
}