import { AlignContentProp, AlignItemsProp, ColumnGapProp, GapProp, GridAutoColumnsProp, GridAutoFlowProp, GridAutoRowsProp, GridTemplateColumnsValue, GridTemplateRowsValue, JustifyContentProp, JustifyItemsProp, ResponsiveProp, RowGapProp, SpacingValue } from "../../styling";
import { ComponentProps, ReactNode } from "react";
import { InternalProps, OmitInternalProps, SlotProps, StyledComponentProps } from "../../shared";
export declare function repeat(count: number | "auto-fill" | "auto-fit", repetition: SpacingValue | SpacingValue[]): string;
export declare function minmax(min: SpacingValue, max: SpacingValue): string;
export declare function fitContent(dimension: SpacingValue): string;
declare const DefaultElement = "div";
export interface InnerGridProps extends SlotProps, InternalProps, Omit<StyledComponentProps<typeof DefaultElement>, "alignContent" | "alignItems" | "columnGap" | "display" | "gap" | "gridAutoColumns" | "gridAutoRows" | "gridAutoFlow" | "gridTemplateAreas" | "gridTemplateColumns" | "gridTemplateRows" | "justifyContent" | "justifyItems" | "rowGap"> {
    /**
     * See [MDN](https://developer.mozilla.org/en-US/docs/Web/CSS/align-content).
     */
    alignContent?: AlignContentProp;
    /**
     * See [MDN](https://developer.mozilla.org/en-US/docs/Web/CSS/align-items).
     */
    alignItems?: AlignItemsProp;
    /**
     * See [MDN](https://developer.mozilla.org/en-US/docs/Web/CSS/grid-template-areas).
     */
    areas?: ResponsiveProp<string[]>;
    /**
     * See [MDN](https://developer.mozilla.org/en-US/docs/Web/CSS/grid-auto-columns).
     */
    autoColumns?: GridAutoColumnsProp;
    /**
     * See [MDN](https://developer.mozilla.org/en-US/docs/Web/CSS/grid-auto-flow).
     */
    autoFlow?: GridAutoFlowProp;
    /**
     * See [MDN](https://developer.mozilla.org/en-US/docs/Web/CSS/grid-auto-rows).
     */
    autoRows?: GridAutoRowsProp;
    /**
     * React children.
     */
    children: ReactNode;
    /**
     * See [MDN](https://developer.mozilla.org/en-US/docs/Web/CSS/column-gap).
     */
    columnGap?: ColumnGapProp;
    /**
     * See [MDN](https://developer.mozilla.org/en-US/docs/Web/CSS/gap).
     */
    gap?: GapProp;
    /**
     * Whether or not the element generate line breaks before or after himself.
     */
    inline?: boolean;
    /**
     * See [MDN](https://developer.mozilla.org/en-US/docs/Web/CSS/justify-content).
     */
    justifyContent?: JustifyContentProp;
    /**
     * See [MDN](https://developer.mozilla.org/en-US/docs/Web/CSS/justify-items).
     */
    justifyItems?: JustifyItemsProp;
    /**
     * See [MDN](https://developer.mozilla.org/en-US/docs/Web/CSS/row-gap).
     */
    rowGap?: RowGapProp;
    /**
     * See [MDN](https://developer.mozilla.org/en-US/docs/Web/CSS/grid-template-columns).
     */
    templateColumns?: ResponsiveProp<GridTemplateColumnsValue | GridTemplateColumnsValue[]>;
    /**
     * See [MDN](https://developer.mozilla.org/en-US/docs/Web/CSS/grid-template-rows).
     */
    templateRows?: ResponsiveProp<GridTemplateRowsValue | GridTemplateRowsValue[]>;
}
export declare function InnerGrid({ areas, as, autoColumns, autoFlow, autoRows, children, forwardedRef, inline, templateColumns, templateRows, ...rest }: InnerGridProps): JSX.Element;
export declare const Grid: import("react").ForwardRefExoticComponent<Pick<OmitInternalProps<InnerGridProps, never>, "children" | "className" | "style" | "slot" | "title" | "filter" | "dir" | "key" | "resize" | "fill" | "id" | "as" | "color" | "content" | "height" | "width" | "defaultChecked" | "defaultValue" | "suppressContentEditableWarning" | "suppressHydrationWarning" | "accessKey" | "contentEditable" | "contextMenu" | "draggable" | "hidden" | "lang" | "placeholder" | "spellCheck" | "tabIndex" | "translate" | "radioGroup" | "role" | "about" | "datatype" | "inlist" | "prefix" | "property" | "resource" | "typeof" | "vocab" | "autoCapitalize" | "autoCorrect" | "autoSave" | "itemProp" | "itemScope" | "itemType" | "itemID" | "itemRef" | "results" | "security" | "unselectable" | "inputMode" | "is" | "aria-activedescendant" | "aria-atomic" | "aria-autocomplete" | "aria-busy" | "aria-checked" | "aria-colcount" | "aria-colindex" | "aria-colspan" | "aria-controls" | "aria-current" | "aria-describedby" | "aria-details" | "aria-disabled" | "aria-dropeffect" | "aria-errormessage" | "aria-expanded" | "aria-flowto" | "aria-grabbed" | "aria-haspopup" | "aria-hidden" | "aria-invalid" | "aria-keyshortcuts" | "aria-label" | "aria-labelledby" | "aria-level" | "aria-live" | "aria-modal" | "aria-multiline" | "aria-multiselectable" | "aria-orientation" | "aria-owns" | "aria-placeholder" | "aria-posinset" | "aria-pressed" | "aria-readonly" | "aria-relevant" | "aria-required" | "aria-roledescription" | "aria-rowcount" | "aria-rowindex" | "aria-rowspan" | "aria-selected" | "aria-setsize" | "aria-sort" | "aria-valuemax" | "aria-valuemin" | "aria-valuenow" | "aria-valuetext" | "dangerouslySetInnerHTML" | "onCopy" | "onCopyCapture" | "onCut" | "onCutCapture" | "onPaste" | "onPasteCapture" | "onCompositionEnd" | "onCompositionEndCapture" | "onCompositionStart" | "onCompositionStartCapture" | "onCompositionUpdate" | "onCompositionUpdateCapture" | "onFocus" | "onFocusCapture" | "onBlur" | "onBlurCapture" | "onChange" | "onChangeCapture" | "onBeforeInput" | "onBeforeInputCapture" | "onInput" | "onInputCapture" | "onReset" | "onResetCapture" | "onSubmit" | "onSubmitCapture" | "onInvalid" | "onInvalidCapture" | "onLoad" | "onLoadCapture" | "onError" | "onErrorCapture" | "onKeyDown" | "onKeyDownCapture" | "onKeyPress" | "onKeyPressCapture" | "onKeyUp" | "onKeyUpCapture" | "onAbort" | "onAbortCapture" | "onCanPlay" | "onCanPlayCapture" | "onCanPlayThrough" | "onCanPlayThroughCapture" | "onDurationChange" | "onDurationChangeCapture" | "onEmptied" | "onEmptiedCapture" | "onEncrypted" | "onEncryptedCapture" | "onEnded" | "onEndedCapture" | "onLoadedData" | "onLoadedDataCapture" | "onLoadedMetadata" | "onLoadedMetadataCapture" | "onLoadStart" | "onLoadStartCapture" | "onPause" | "onPauseCapture" | "onPlay" | "onPlayCapture" | "onPlaying" | "onPlayingCapture" | "onProgress" | "onProgressCapture" | "onRateChange" | "onRateChangeCapture" | "onSeeked" | "onSeekedCapture" | "onSeeking" | "onSeekingCapture" | "onStalled" | "onStalledCapture" | "onSuspend" | "onSuspendCapture" | "onTimeUpdate" | "onTimeUpdateCapture" | "onVolumeChange" | "onVolumeChangeCapture" | "onWaiting" | "onWaitingCapture" | "onAuxClick" | "onAuxClickCapture" | "onClick" | "onClickCapture" | "onContextMenu" | "onContextMenuCapture" | "onDoubleClick" | "onDoubleClickCapture" | "onDrag" | "onDragCapture" | "onDragEnd" | "onDragEndCapture" | "onDragEnter" | "onDragEnterCapture" | "onDragExit" | "onDragExitCapture" | "onDragLeave" | "onDragLeaveCapture" | "onDragOver" | "onDragOverCapture" | "onDragStart" | "onDragStartCapture" | "onDrop" | "onDropCapture" | "onMouseDown" | "onMouseDownCapture" | "onMouseEnter" | "onMouseLeave" | "onMouseMove" | "onMouseMoveCapture" | "onMouseOut" | "onMouseOutCapture" | "onMouseOver" | "onMouseOverCapture" | "onMouseUp" | "onMouseUpCapture" | "onSelect" | "onSelectCapture" | "onTouchCancel" | "onTouchCancelCapture" | "onTouchEnd" | "onTouchEndCapture" | "onTouchMove" | "onTouchMoveCapture" | "onTouchStart" | "onTouchStartCapture" | "onPointerDown" | "onPointerDownCapture" | "onPointerMove" | "onPointerMoveCapture" | "onPointerUp" | "onPointerUpCapture" | "onPointerCancel" | "onPointerCancelCapture" | "onPointerEnter" | "onPointerEnterCapture" | "onPointerLeave" | "onPointerLeaveCapture" | "onPointerOver" | "onPointerOverCapture" | "onPointerOut" | "onPointerOutCapture" | "onGotPointerCapture" | "onGotPointerCaptureCapture" | "onLostPointerCapture" | "onLostPointerCaptureCapture" | "onScroll" | "onScrollCapture" | "onWheel" | "onWheelCapture" | "onAnimationStart" | "onAnimationStartCapture" | "onAnimationEnd" | "onAnimationEndCapture" | "onAnimationIteration" | "onAnimationIterationCapture" | "onTransitionEnd" | "onTransitionEndCapture" | "alignContent" | "alignItems" | "alignSelf" | "aspectRatio" | "backgroundColor" | "backgroundColorActive" | "backgroundColorFocus" | "backgroundColorHover" | "backgroundImage" | "backgroundPosition" | "backgroundRepeat" | "backgroundSize" | "border" | "borderBottom" | "borderBottomActive" | "borderBottomFocus" | "borderBottomHover" | "borderBottomLeftRadius" | "borderBottomRightRadius" | "borderActive" | "borderFocus" | "borderHover" | "borderLeft" | "borderLeftActive" | "borderLeftFocus" | "borderLeftHover" | "borderRadius" | "borderRight" | "borderRightActive" | "borderRightFocus" | "borderRightHover" | "borderTop" | "borderTopActive" | "borderTopFocus" | "borderTopHover" | "borderTopLeftRadius" | "borderTopRightRadius" | "bottom" | "boxShadow" | "boxShadowActive" | "boxShadowFocus" | "boxShadowHover" | "colorActive" | "colorFocus" | "colorHover" | "columnGap" | "contentVisibility" | "cursor" | "cursorHover" | "fillFocus" | "fillHover" | "flex" | "flexBasis" | "flexDirection" | "flexFlow" | "flexGrow" | "flexShrink" | "flexWrap" | "fontSize" | "fontStyle" | "fontWeight" | "gap" | "grid" | "gridArea" | "gridColumn" | "gridColumnEnd" | "gridColumnSpan" | "gridColumnStart" | "gridRow" | "gridRowEnd" | "gridRowSpan" | "gridRowStart" | "gridTemplate" | "justifyContent" | "justifyItems" | "justifySelf" | "left" | "letterSpacing" | "lineHeight" | "margin" | "marginBottom" | "marginLeft" | "marginRight" | "marginTop" | "marginX" | "marginY" | "maxHeight" | "maxWidth" | "minHeight" | "minWidth" | "objectFit" | "objectPosition" | "opacity" | "opacityActive" | "opacityFocus" | "opacityHover" | "order" | "outline" | "outlineFocus" | "overflow" | "overflowX" | "overflowY" | "padding" | "paddingBottom" | "paddingLeft" | "paddingRight" | "paddingTop" | "paddingX" | "paddingY" | "pointerEvents" | "position" | "right" | "rowGap" | "stroke" | "textAlign" | "textDecoration" | "textOverflow" | "textTransform" | "top" | "transform" | "transformOrigin" | "transformStyle" | "verticalAlign" | "visibility" | "whiteSpace" | "willChange" | "wordBreak" | "zIndex" | "inline" | "areas" | "autoColumns" | "autoFlow" | "autoRows" | "templateColumns" | "templateRows"> & import("react").RefAttributes<any>>;
export declare type GridProps = ComponentProps<typeof Grid>;
export {};
