import { FocusEvent, SyntheticEvent } from "react";
import { OverlayPosition } from "./useOverlayPosition";
import { ResponsiveProp } from "../../styling";
export declare type PopupAlignment = "start" | "end";
export declare type PopupDirection = "top" | "bottom";
export declare type PopupPosition = OverlayPosition;
export declare type PopupAlignmentProp = ResponsiveProp<PopupAlignment>;
export declare type PopupDirectionProp = ResponsiveProp<PopupDirection>;
export declare type PopupPositionProp = ResponsiveProp<PopupPosition>;
export declare type PopupTrigger = "none" | "click";
export interface PopupProps {
    /**
     * The horizontal alignment of the popup relative to the trigger.
     */
    align?: PopupAlignment;
    /**
     * Whether or not the popup can flip when it will overflow it's boundary area.
     */
    allowFlip?: boolean;
    /**
     * Whether or not the popup position can change to prevent it from being cut off so that it stays visible within its boundary area.
     */
    allowPreventOverflow?: boolean;
    /**
     * The initial value of open when in auto controlled mode.
     */
    defaultOpen?: boolean;
    /**
     * The direction the open will open relative to the trigger.
     */
    direction?: PopupDirection;
    /**
     * Called when the open state change.
     * @param {SyntheticEvent} event - React's original event.
     * @param {boolean} isOpen - Indicate if the popup is visible.
     * @returns {void}
     */
    onOpenChange?: (event: SyntheticEvent, isOpen: boolean) => void;
    /**
     * Whether or not to show the popup.
     */
    open?: boolean;
    /**
     * The z-index of the menu.
     */
    zIndex?: number;
}
export interface UsePopupOptions {
    allowFlip?: boolean;
    allowPreventOverflow?: boolean;
    boundaryElement?: HTMLElement;
    defaultOpen?: boolean;
    disabled?: boolean;
    hasArrow?: boolean;
    hideOnEscape?: boolean;
    hideOnLeave?: boolean;
    hideOnOutsideClick?: boolean;
    id?: string;
    keyProp?: string;
    offset?: number[];
    onOpenChange?: (event: SyntheticEvent, newValue: boolean) => void;
    open?: boolean | null;
    position?: PopupPosition;
    restoreFocus?: boolean;
    trigger?: PopupTrigger;
}
export declare function usePopup(type: "menu" | "listbox" | "dialog", { allowFlip, allowPreventOverflow, boundaryElement, defaultOpen, disabled, hasArrow, hideOnEscape, hideOnLeave, hideOnOutsideClick, id, keyProp, offset, onOpenChange, open, position, restoreFocus, trigger }?: UsePopupOptions): {
    arrowProps: {
        ref?: undefined;
    } | {
        ref: import("../../shared").MergedRef<HTMLElement>;
    };
    focusManager: import("../../shared").FocusManager;
    focusScope: import("../../shared").DomScope;
    isOpen: boolean;
    overlayProps: {
        onKeyDown: (event: import("react").KeyboardEvent<Element>) => void;
    } & {
        onKeyDown?: undefined;
    } & {
        onKeyDown: (event: import("react").KeyboardEvent<Element>) => void;
    } & {
        id: string;
        ref: import("../../shared").MergedRef<HTMLElement>;
        show: boolean;
    };
    setIsOpen: (event: SyntheticEvent, newValue: boolean) => void;
    triggerProps: {
        onClick?: undefined;
        onKeyDown?: undefined;
        onKeyUp?: undefined;
        onBlur?: undefined;
        onFocus?: undefined;
        onMouseEnter?: undefined;
    } & {
        onClick: (event: SyntheticEvent<Element, Event>) => void;
        onKeyDown: (event: import("react").KeyboardEvent<Element>) => void;
        onKeyUp: (event: import("react").KeyboardEvent<Element>) => void;
        onBlur?: undefined;
        onFocus?: undefined;
        onMouseEnter?: undefined;
    } & {
        onBlur: (event: FocusEvent<Element, Element>) => void;
        onFocus: (event: FocusEvent<Element, Element>) => void;
        onMouseEnter: (event: import("react").MouseEvent<Element, MouseEvent>) => void;
        onClick?: undefined;
        onKeyDown?: undefined;
        onKeyUp?: undefined;
    } & {
        "aria-controls": string;
        "aria-expanded": boolean;
        "aria-haspopup": "dialog" | "menu" | "listbox";
        ref: import("../../shared").MergedRef<HTMLElement>;
        tabIndex: number;
    };
};
