import "./RadioGroup.css";
import { useGroupInput } from "../../input";
import { CheckableContext, Keys, augmentElement, isNil, isNumber, mergeProps, omitProps, useAutoFocusChild, useControllableState, useEventCallback, useFocusManager, useFocusScope, useId, useKeyboardNavigation, useKeyedRovingFocus, useMergedRefs } from "../../shared";
import { Children, forwardRef } from "react";
import { Group } from "../../group";
import { useFieldInputProps } from "../../field";
import { useResponsiveValue } from "../../styling";
import { useToolbarProps } from "../../toolbar";
import { jsx as _jsx } from "react/jsx-runtime";
const DefaultElement = "div";
const NavigationKeyBinding = {
  default: {
    first: [Keys.home],
    last: [Keys.end],
    next: [Keys.arrowRight, Keys.arrowDown],
    previous: [Keys.arrowLeft, Keys.arrowUp]
  },
  toolbar: {
    next: [Keys.arrowDown],
    previous: [Keys.arrowUp]
  }
};
const RadioKeyProp = "value";
export function InnerRadioGroup(props) {
  const [toolbarProps, isInToolbar] = useToolbarProps();
  const [fieldProps, isInField] = useFieldInputProps();
  const {
    as = DefaultElement,
    autoFocus,
    children,
    defaultValue,
    disabled,
    forwardedRef,
    gap,
    name,
    onChange,
    orientation = "vertical",
    required,
    reverse,
    validationState,
    value,
    wrap = true,
    ...rest
  } = mergeProps(props, toolbarProps, omitProps(fieldProps, ["fluid", "size"]));
  const wrapValue = useResponsiveValue(wrap);
  const [checkedValue, setCheckedValue] = useControllableState(value, defaultValue, null);
  const [focusScope, setFocusRef] = useFocusScope();
  const groupRef = useMergedRefs(setFocusRef, forwardedRef);
  const handleArrowSelect = useEventCallback((event, element) => {
    // When a number value is provided it's converted to a string when a new value is selected using the keyboard arrows.
    const newValue = element.dataset.type === "number" ? parseInt(element.value) : element.value;
    setCheckedValue(newValue);
  });
  const focusManager = useFocusManager(focusScope, {
    keyProp: RadioKeyProp
  });
  useKeyedRovingFocus(focusScope, checkedValue, {
    keyProp: RadioKeyProp
  });
  useAutoFocusChild(focusManager, {
    delay: isNumber(autoFocus) ? autoFocus : undefined,
    isDisabled: !autoFocus,
    target: value !== null && value !== void 0 ? value : defaultValue
  });
  const navigationMode = isInToolbar ? "toolbar" : "default";
  const navigationProps = useKeyboardNavigation(focusManager, NavigationKeyBinding[navigationMode], !isInToolbar ? {
    onSelect: handleArrowSelect
  } : undefined);
  const {
    groupProps,
    itemProps
  } = useGroupInput({
    cssModule: "o-ui-radio-group",
    disabled,
    gap,
    groupRef,
    isInField,
    orientation,
    required,
    reverse,
    role: "radiogroup",
    validationState,
    wrap: wrapValue
  });
  const handleCheck = useEventCallback((event, newValue) => {
    if (!isNil(onChange)) {
      onChange(event, newValue);
    }

    setCheckedValue(newValue);
  });
  const groupName = useId(name, "radio-group");
  return /*#__PURE__*/_jsx(Group, { ...mergeProps(rest, {
      as
    }, navigationProps, groupProps),
    children: /*#__PURE__*/_jsx(CheckableContext.Provider, {
      value: {
        checkedValue,
        onCheck: handleCheck
      },
      children: Children.toArray(children).filter(x => x).map((x, index) => {
        return augmentElement(x, { ...itemProps,
          name: groupName,
          role: "radio",
          value: index.toString()
        });
      })
    })
  });
}
export const RadioGroup = /*#__PURE__*/forwardRef((props, ref) => /*#__PURE__*/_jsx(InnerRadioGroup, { ...props,
  forwardedRef: ref
}));