import { useCallback, useMemo } from "react";
import { useRefState } from "./useRefState";
import { walkFocusableElements } from "./focusableTreeWalker";
export class DomScope {
  constructor(scopeRef, handlersRef) {
    this.scopeRef = void 0;
    this.handlersRef = void 0;
    this.scopeRef = scopeRef;
    this.handlersRef = handlersRef;
  }

  get elements() {
    return this.scopeRef.current;
  }

  registerChangeHandler(handler) {
    this.handlersRef.current.push(handler);
  }

  removeChangeHandler(handler) {
    const handlers = this.handlersRef.current;
    handlers.splice(handlers.indexOf(handler), 1);
  }

  isInScope(element) {
    return this.elements.some(x => x.contains(element));
  }

}
export function useFocusScope() {
  const [scopeRef, setScope] = useRefState([]);
  const [handlersRef] = useRefState([]);
  const setRef = useCallback(rootElement => {
    const setElements = elements => {
      handlersRef.current.forEach(x => {
        x(elements, scopeRef.current);
      });
      setScope(elements);
    };

    const parseElements = () => {
      const scope = [];
      walkFocusableElements(rootElement, x => {
        scope.push(x);
      });
      setElements(scope);
    }; // Watch for dynamic elements.


    const mutationObserver = new MutationObserver(() => {
      parseElements();
    });

    if (rootElement) {
      // Parse initial elements.
      parseElements();
      mutationObserver.observe(rootElement, {
        childList: true,
        subtree: true
      });
    } else {
      mutationObserver.disconnect(); // HACK: It's probably not a good idea to comment this cleanup code but it's currently the only way
      // for restore focus to work.
      // setElements([]);
    }
  }, [scopeRef, setScope, handlersRef]);
  const scope = useMemo(() => new DomScope(scopeRef, handlersRef), [scopeRef, handlersRef]);
  return [scope, setRef];
}