import { isNil } from "./assertions";
import { useEventCallback } from "./useEventCallback";
export function useKeyboardNavigation(focusManager, {
  previous = [],
  next = [],
  first = [],
  last = []
}, {
  onSelect
} = {}) {
  const handleKeyDown = useEventCallback(event => {
    const key = event.key;

    const handleFocus = element => {
      if (!isNil(onSelect)) {
        onSelect(event, element);
      }
    };

    if (previous.includes(key)) {
      event.preventDefault();
      focusManager.focusPrevious({
        onFocus: handleFocus
      });
    } else if (next.includes(key)) {
      event.preventDefault();
      focusManager.focusNext({
        onFocus: handleFocus
      });
    } else if (first.includes(key)) {
      event.preventDefault();
      focusManager.focusFirst({
        onFocus: handleFocus
      });
    } else if (last.includes(key)) {
      event.preventDefault();
      focusManager.focusLast({
        onFocus: handleFocus
      });
    }
  });
  return {
    onKeyDown: handleKeyDown
  };
}