// Strongly inspired by https://github.com/react-restart/hooks/blob/master/src/useResizeObserver.ts.
import { useCallback, useRef } from "react";
import { isFunction, isNil } from "./assertions";
const handlersMap = new WeakMap();
let observer;

function getResizeObserver() {
  return observer = observer || new ResizeObserver(entries => {
    entries.forEach(entry => {
      const handler = handlersMap.get(entry.target);

      if (isFunction(handler)) {
        handler(entry);
      }
    });
  });
}

export const useResizeObserver = (onResize, {
  box,
  isDisabled
} = {}) => {
  const elementRef = useRef(null);
  const dispose = useCallback(() => {
    const element = elementRef.current;

    if (!isNil(element)) {
      elementRef.current = null;

      if (!handlersMap.has(element)) {
        getResizeObserver().unobserve(element);
      }

      handlersMap.delete(element);
    }
  }, [elementRef]);

  const resizeRef = element => {
    dispose();

    if (!isDisabled) {
      if (!isNil(element)) {
        elementRef.current = element;
        getResizeObserver().observe(element, {
          box
        });
        handlersMap.set(element, onResize);
      }
    }
  };

  return resizeRef;
};